@@ -335,7 +335,7 @@ EAction.prototype.showUiOptions = function(resume, restoreFromSettings) {
             var iconLabel = optionsToolBar.findChild("Icon");
             if (!isNull(iconLabel)) {
                 iconLabel.toolTip = qsTr("Active Tool:") + " " + guiAction.text.replace("&", "");
-                iconLabel.pixmap = guiAction.icon.pixmap(EAction.getOptionsToolBar().iconSize);
+                OptionsToolBar.setIcon(guiAction.icon);
                 iconLabel.setFixedWidth(iconLabel.height + 12);
             }
         }
@@ -469,8 +469,7 @@ EAction.prototype.hideUiOptions = function(saveToSettings) {
         if (!this.getGuiAction().icon.isNull()) {
             var iconLabel = optionsToolBar.findChild("Icon");
             if (!isNull(iconLabel)) {
-                var icon = new QIcon(autoPath("scripts/Reset/Reset.svg"));
-                iconLabel.pixmap = icon.pixmap(EAction.getOptionsToolBar().iconSize);
+                OptionsToolBar.setIcon("scripts/Reset/Reset.svg");
                 iconLabel.toolTip = qsTr("Active Tool:") + " " + qsTr("None");
             }
         }
