@@ -893,18 +893,20 @@ PropertyEditorImpl.prototype.initNumberControls = function(objectName, propertyT
         newText = PropertyEditor.varies;
     }
     else {
-        if (attributes.isAngleType()) {
-            value = RMath.rad2deg(value);
-        }
-        var document = EAction.getDocument();
-        if (!attributes.isAngleType() &&
-            (document.getLinearFormat()===RS.Fractional ||
-             document.getLinearFormat()===RS.FractionalStacked)) {
+        if (!isNull(value)) {
+            if (attributes.isAngleType()) {
+                value = RMath.rad2deg(value);
+            }
+            var document = EAction.getDocument();
+            if (!attributes.isAngleType() &&
+                (document.getLinearFormat()===RS.Fractional ||
+                 document.getLinearFormat()===RS.FractionalStacked)) {
 
-            newText = RUnit.getLabel(value, document, 8);
-        }
-        else {
-            newText = sprintf("%.6f", value);
+                newText = RUnit.getLabel(value, document, 8);
+            }
+            else {
+                newText = sprintf("%.6f", value);
+            }
         }
     }
 
