@@ -1183,6 +1183,24 @@ function deepCopy(obj) {
     return obj;
 }
 
+function hasOwnPropertyCI(obj, prop) {
+   return Object.keys(obj)
+           .filter(function (v) {
+               return v.toLowerCase() === prop.toLowerCase();
+           }).length > 0;
+}
+
+function getOwnPropertyCI(obj, prop) {
+    var ret = Object.keys(obj)
+            .filter(function (v) {
+                return v.toLowerCase() === prop.toLowerCase();
+            });
+    if (ret.length>0) {
+        return obj[ret[0]];
+    }
+    return undefined;
+}
+
 /**
  * \return A new array which contains every unique item of this array only once.
  */
@@ -2061,6 +2079,13 @@ function addDirtyFlag(title) {
 }
 
 function hasPlugin(name) {
+    if (name==="PROTOOLS") {
+        if (new QFileInfo("scripts/Pro").exists()) {
+            // PROTOOLS available not as plugins but as scripts folder:
+            return true;
+        }
+    }
+
     return RPluginLoader.hasPlugin(name);
 }
 
@@ -2121,8 +2146,76 @@ function restoreOverrideCursor() {
     }
 }
 
+function initUserShortcuts() {
+    var settings = RSettings.getQSettings();
+    var keys = RSettings.getAllKeys("Shortcuts");
+
+    var i, key, action;
+
+    for (i=0; i<keys.length; i++) {
+        key = keys[i];
+        action = RGuiAction.getByScriptFile(key);
+        if (isNull(action)) {
+            continue;
+        }
+        var scStringList = settings.value("Shortcuts/" + key);
+
+        // explicitely no shortcuts:
+        if (isNull(scStringList)) {
+            action.setShortcuts([]);
+            continue;
+        }
+
+        var scList = [];
+        for (var k=0; k<scStringList.length; k++) {
+            var sc = new QKeySequence(scStringList[k]);
+            scList.push(sc);
+        }
+        action.setShortcuts(scList);
+    }
+
+    keys = RSettings.getAllKeys("Commands");
+
+    for (i=0; i<keys.length; i++) {
+        key = keys[i];
+        action = RGuiAction.getByScriptFile(key);
+        if (isNull(action)) {
+            continue;
+        }
+        var cmStringList = settings.value("Commands/" + key);
+
+        // explicitely no commands:
+        if (isNull(cmStringList)) {
+            action.setCommands([]);
+            continue;
+        }
+
+        action.setCommands(cmStringList);
+    }
+}
+
 function addActionsToWidgets() {
+    initUserShortcuts();
+
     var appWin = RMainWindowQt.getMainWindow();
+
+    // delete previous shortcut delegates:
+    // part of workaround for QTBUG-38256, QTBUG-57990:
+    if ((RSettings.getQtVersion()<0x050500 && RSettings.getQtVersion()>=0x050000) ||
+        (RSettings.getQtVersion()===0x050800 && RS.getSystemId()==="linux")) {
+
+        var scObjs = appWin.property("DelegatedShortcutsObjs");
+        if (!isNull(scObjs)) {
+            for (var si=0; si<scObjs.length; si++) {
+                if (isNull(scObjs[si])) {
+                    continue;
+                }
+                scObjs[si].destroy();
+            }
+        }
+        appWin.setProperty("DelegatedShortcutsObjs", []);
+    }
+
     var actions = RGuiAction.getActions();
     var widgetTypes = ["Menu", "ToolBar", "MatrixPanel", "Panel"];
     for (var c=0; c<actions.length; ++c) {
@@ -2168,16 +2261,35 @@ function addActionsToWidgets() {
             var w = appWin.findChild(wn);
             if (!isNull(w)) {
 
-                // workaround for QTBUG-38256 (action not triggered for letter based shortcuts in sub menus)
-                if (RSettings.getQtVersion()<0x050500 && RSettings.getQtVersion()>=0x050000) {
-                    if (isOfType(w.parentWidget(), QMenu)) {
-                        new QShortcut(a.shortcut, a.parentWidget(), 0, 0,  Qt.WindowShortcut).activated.connect(a, "trigger");
+                // workaround for QTBUG-38256 (action not triggered for letter based shortcuts in SUB menus):
+                // workaround for QTBUG-57990 (action not triggered for letter based shortcuts in ALL menus):
+                if ((RSettings.getQtVersion()<0x050500 && RSettings.getQtVersion()>=0x050000) ||
+                    (RSettings.getQtVersion()===0x050800 && RS.getSystemId()==="linux")) {
+
+                    if (k===0) {
+                        var shortcuts = a.shortcuts();
+
+                        var scObjs = appWin.property("DelegatedShortcutsObjs");
+                        if (isNull(scObjs)) {
+                            scObjs=[];
+                        }
+                        for (var si=0; si<shortcuts.length; si++) {
+                            var scObj = new QShortcut(shortcuts[si], a.parentWidget(), 0, 0, Qt.WindowShortcut)
+                            scObj.activated.connect(a, "trigger");
+                            scObjs.push(scObj);
+                        }
+                        appWin.setProperty("DelegatedShortcutsObjs", scObjs);
 
-                        // avoid 'Ambiguous shortcut overload' when tool buttons visible:
                         var sc = a.shortcut.toString();
                         if (sc.length>0) {
-                            a.setShortcutText(" " + sc);
+                            if (RS.getSystemId()==="linux") {
+                                a.setShortcutText("[" + sc + "]");
+                            }
+                            else {
+                                a.setShortcutText(" " + sc);
+                            }
                         }
+                        a.setProperty("DelegatedShortcuts", shortcuts);
                         a.setDefaultShortcuts([]);
                     }
                 }
@@ -2303,6 +2415,30 @@ function applyTheme() {
     }
 }
 
+function readTextFile(fileName) {
+    var file = new QFile(fileName);
+    var flags = new QIODevice.OpenMode(QIODevice.ReadOnly | QIODevice.Text);
+    if (file.open(flags)) {
+        var textStream = new QTextStream(file);
+        var contents = textStream.readAll();
+        file.close();
+        return contents;
+    }
+
+    return undefined;
+}
+
+function writeTextFile(fileName, str) {
+    var file = new QFile(fileName);
+    var flags = new QIODevice.OpenMode(QIODevice.WriteOnly | QIODevice.Text);
+    if (file.open(flags)) {
+        var textStream = new QTextStream(file);
+        textStream.writeString(str);
+    }
+    file.close();
+};
+
+
 // fix QPlainTextEdit API for Qt 5:
 if (!isFunction(QPlainTextEdit.prototype.toPlainText)) {
     QPlainTextEdit.prototype.toPlainText = function() {
